from enum import StrEnum


class NotifyType(StrEnum):
    FEISHU_USER_TEXT = "feishu_user_text"
    FEISHU_USER_RICH_TEXT = "feishu_user_rich_text"
    FEISHU_GROUP_TEXT = "feishu_group_text"
    FEISHU_GROUP_MESSAGE_CARD = "feishu_group_message_card"



ENDPOINT = 'http://47.238.228.17:10010'
NOTIFY_AUTH_TOKEN = 'SAIS_NOTIFY_AUTH_TOKEN'

SAIS_ROBOT_NAME = 'sais-post-robot'
NOTIFY_SERVICE_NOTIFY_TYPE_FEISHU = 'feishu'
NOTIFY_SERVICE_NOTIFY_TYPE_FEISHU_GROUP = 'feishu_group'
LOGGER_NAME = 'sais.notify'



import os

from sais.notify.config.const import NOTIFY_AUTH_TOKEN


class EnvVarCredentialsProvider:
    def __init__(self):
        self.token = self.__get_credentials()

    def __get_credentials(self):
        bearer_token = os.getenv()
        if not bearer_token:
            raise ValueError(f'{NOTIFY_AUTH_TOKEN} should not be null or empty.')
        return f'Bearer {bearer_token}'